****************************************
Convolution and Pooling
****************************************

Convolution and pooling operations are provided in the module ``ANNarchy.extensions.convolution``. They must be explicitely imported::

    from ANNarchy import *
    from ANNarchy.extensions.convolution import *


Class Convolution
===============================

.. autoclass:: ANNarchy.extensions.convolution.Convolution
    :members:

Class Pooling
===============================

.. autoclass:: ANNarchy.extensions.convolution.Pooling
    :members:

Class Copy
===============================

.. autoclass:: ANNarchy.extensions.convolution.Copy
    :members:

